<template>
  <div class="flv-player-container">
    <div v-if="!supported" class="error-message">
      您的浏览器不支持 FLV 直播播放
    </div>
    <div v-else class="video-player">
      <video
        ref="videoElement"
        autoplay
        muted
        class="video-js"
      ></video>
      <div v-if="error" class="error-message">
        <span>{{ error }}</span>
        <!-- <button class="refresh-button" @click="refresh">
          <i class="el-icon-refresh"></i>
          重新加载
        </button> -->
      </div>
      <div v-if="loading" class="loading-message">正在加载直播流...</div>
      <div class="controls">
        <el-tooltip content="播放/暂停" placement="top" :open-delay="500">
          <el-button class="control-btn" circle @click="togglePlay">
            <i :class="isPlaying ? 'el-icon-video-pause' : 'el-icon-video-play'"></i>
          </el-button>
        </el-tooltip>

        <el-tooltip content="设备信息" placement="top" :open-delay="500">
          <el-button class="control-btn" circle @click="showDeviceInfo">
            <i class="el-icon-info"></i><el-icon><VideoCamera /></el-icon>
          </el-button>
        </el-tooltip>
        <el-tooltip content="云台操作" placement="top" :open-delay="500">
          <el-button class="control-btn" circle @click="togglePtz">
            <i class="el-icon-help"></i>
          </el-button>
        </el-tooltip>
        <el-tooltip content="旋转画面" placement="top" :open-delay="500">
          <el-button class="control-btn" circle @click="rotateVideo">
            <i class="el-icon-refresh"></i>
          </el-button>
        </el-tooltip>
        <el-tooltip content="截图" placement="top" :open-delay="500">
          <el-button class="control-btn" circle @click="takeSnapshot">
            <i class="el-icon-camera"></i>
          </el-button>
        </el-tooltip>
        <el-tooltip :content="isRecording ? '结束录制' : '开始录制'" placement="top" :open-delay="500">
          <el-button 
            class="control-btn" 
            circle 
            @click="toggleRecording"
            :type="isRecording ? 'primary' : ''"
          >
            <i class="el-icon-video-camera"></i>
          </el-button>
        </el-tooltip>
        <el-tooltip :content="isTalking ? '结束喊话' : '喊话'" placement="top" :open-delay="500">
          <el-button class="control-btn" circle @click="startTalk" :type="isTalking ? 'primary' : ''">
            <i class="el-icon-microphone"></i>
          </el-button>
        </el-tooltip>

        <el-tooltip content="全屏" placement="top" :open-delay="500">
          <el-button class="control-btn" circle @click="fullscreen">
            <i class="el-icon-full-screen"></i>
          </el-button>
        </el-tooltip>
      </div>
      <div class="record-controls">
        <div class="record-status" v-if="isRecording">
          <span class="record-indicator"></span>
          正在录制... {{ formatRecordingTime }}
        </div>
      </div>
      
      <!-- 设备信息对话框 -->
      <el-dialog
        title="设备信息"
        :visible.sync="deviceInfoVisible"
        width="300px"
        :modal="false" 
        :append-to-body=true
        custom-class="device-info-dialog"
      >
        <div class="device-info">
          <p><strong>设备ID：</strong>{{ deviceInfo.deviceId || '-' }}</p>
          <p><strong>设备名称：</strong>{{ deviceInfo.deviceName || '-' }}</p>
          <p><strong>设备类型：</strong>{{ deviceInfo.deviceType || '-' }}</p>
          <p><strong>在线状态：</strong>{{ deviceInfo.online ? '在线' : '离线' }}</p>
          <p><strong>分辨率：</strong>{{ deviceInfo.resolution || '-' }}</p>
          <p><strong>码率：</strong>{{ deviceInfo.bitrate || '-' }}</p>
        </div>
      </el-dialog>
    </div>
  </div>
</template>

<script>
import flvjs from 'flv.js'
import { getDeviceList, getChannelList, getDeviceInfo } from '@/api/video-controller.js'

export default {
  name: 'FLVPlayer',
  props: {
    url: {
      type: String,
      required: true
    },
    deviceId: {
      type: String,
      default: ''
    },
    deviceName: {
      type: String,
      default: ''
    },
    deviceType: {
      type: String,
      default: ''
    }
  },
      data() {
        return {
          flvPlayer: null,
          isPlaying: false,
          isMuted: true, // 默认静音，避免自动播放策略问题
          loading: false,
          error: null,
          supported: flvjs.isSupported(),
          // 新增状态
          rotationDegree: 0,
          isTalking: false,
          deviceInfoVisible: false,
          deviceInfo: {
            deviceId: '',
            deviceName: '',
            deviceType: '',
            online: false,
            resolution: '',
            bitrate: ''
          },
          userId: process.env.VUE_APP_HUAWEI_USER_ID,
          channelId: '44000000001310000099',
          isRecording: false,
          mediaRecorder: null, // MediaRecorder实例
          recordedChunks: [], // 录制的数据块
          recordingStartTime: null,
          recordingDuration: 0,
          recordingTimer: null,
          resizeTimer: null, // 用于窗口大小变化的防抖处理
          frameTimer: null // 用于录制时的帧捕获
        }
  },
  watch: {
    url() {
      this.destroyPlayer()
      this.initPlayer()
    }
  },
  computed: {
    formatRecordingTime() {
      const minutes = Math.floor(this.recordingDuration / 60);
      const seconds = this.recordingDuration % 60;
      return `${minutes.toString().padStart(2, '0')}:${seconds.toString().padStart(2, '0')}`;
    }
  },
  mounted() {
    if (this.supported) {
      this.initPlayer();
    }
    
    // 添加视频元数据加载事件监听
    const videoElement = this.$refs.videoElement;
    if (videoElement) {
      videoElement.addEventListener('loadedmetadata', this.handleVideoMetadata);
    }

    // 添加窗口大小变化监听
    window.addEventListener('resize', this.handleResize);

    // 初始化设备信息
    this.deviceInfo.deviceId = this.deviceId;
    this.deviceInfo.deviceName = this.deviceName;
    this.deviceInfo.deviceType = this.deviceType;

    // 初始化视频容器类名
    if (videoElement?.parentElement) {
      videoElement.parentElement.classList.add('rotate-0');
    }
  },

  beforeDestroy() {
    // 清理播放器
    this.destroyPlayer();

    // 移除事件监听
    const videoElement = this.$refs.videoElement;
    if (videoElement) {
      videoElement.removeEventListener('loadedmetadata', this.handleVideoMetadata);
    }
    window.removeEventListener('resize', this.handleResize);

    // 停止喊话（如果正在进行）
    if (this.isTalking) {
      this.stopTalk();
    }

    // 重置视频旋转
    if (this.rotationDegree !== 0 && videoElement) {
      videoElement.style.transform = '';
      videoElement.style.maxWidth = '';
      videoElement.style.maxHeight = '';
    }

    // 清理所有计时器
    this.clearRecordingTimer();
    if (this.resizeTimer) {
      clearTimeout(this.resizeTimer);
      this.resizeTimer = null;
    }
    if (this.frameTimer) {
      clearInterval(this.frameTimer);
      this.frameTimer = null;
    }

    // 清理录制相关资源
    if (this.mediaRecorder && this.mediaRecorder.state !== 'inactive') {
      this.mediaRecorder.stop();
    }
    this.recordedChunks = [];
  },
  methods: {
    refresh() {
      this.$emit('refresh', this.deviceId);
    },
    initPlayer() {
      if (!this.url) {
        this.error = '播放地址不能为空'
        return
      }

      if (this.flvPlayer) {
        this.destroyPlayer()
      }

      this.loading = true
      this.error = null

      const videoElement = this.$refs.videoElement
      if (!videoElement) return

      if (flvjs.isSupported()) {
        this.flvPlayer = flvjs.createPlayer({
          type: 'flv',
          url: this.url,
          isLive: true,
          hasAudio: false,
          transcode: {
            video: 'avc1.42E01E', // 强制转换为Baseline Profile
            audio: false
          },
          reuseRedirectedURL: true,
          lazyLoad: false,
          seekType: 'range', // 重要：使用range请求
          rangeLoadZeroStart: true,
        }, {
          enableWorker: false, // 禁用Web Worker避免某些环境问题
          enableStashBuffer: false,
          autoCleanupSourceBuffer: true,
          stashInitialSize: 256
        });

        this.flvPlayer.attachMediaElement(videoElement)
        this.flvPlayer.load()

        this.flvPlayer.on(flvjs.Events.ERROR, (errType, errDetail) => {
          // console.error('FLV播放错误:', errType, errDetail)
          this.error = `播放错误: ${errType} - ${errDetail}`
          this.loading = false
        })

        this.flvPlayer.on(flvjs.Events.LOADING_COMPLETE, () => {
          this.loading = false
          this.isPlaying = true
        })

        try {
          this.flvPlayer.play()
        } catch (err) {
          this.error = `播放失败: ${err.message}`
          console.error('播放失败:', err)
        } finally {
          this.loading = false
        }
      }
    },
    destroyPlayer() {
      if (this.flvPlayer) {
        this.flvPlayer.pause()
        this.flvPlayer.unload()
        this.flvPlayer.detachMediaElement()
        this.flvPlayer.destroy()
        this.flvPlayer = null
      }
      this.isPlaying = false
    },
    togglePlay() {
      if (!this.flvPlayer) return

      if (this.isPlaying) {
        this.flvPlayer.pause()
      } else {
        this.flvPlayer.play()
      }
      this.isPlaying = !this.isPlaying
    },
    toggleMute() {
      const videoElement = this.$refs.videoElement
      if (videoElement) {
        videoElement.muted = !videoElement.muted
        this.isMuted = videoElement.muted
      }
    },
    togglePtz() {
      this.$emit('toggleControlPanel')
    },
    fullscreen() {
      const videoElement = this.$refs.videoElement
      if (videoElement) {
        if (videoElement.requestFullscreen) {
          videoElement.requestFullscreen()
        } else if (videoElement.webkitRequestFullscreen) {
          videoElement.webkitRequestFullscreen()
        } else if (videoElement.msRequestFullscreen) {
          videoElement.msRequestFullscreen()
        }
      }
    },
    // 切换录像状态
    toggleRecording() {
      console.log('toggleRecording', this.isRecording);
      if (this.isRecording) {
        this.stopRecording();
        clearInterval(this.recordingTimer);
        this.recordingTimer = null;
      } else {
        this.startRecording();
        this.recordingStartTime = new Date();
        this.recordingDuration = 0;
        this.recordingTimer = setInterval(() => {
          this.recordingDuration = Math.floor((new Date() - this.recordingStartTime) / 1000);
        }, 1000);
      }
    },
    
    // 开始录像
    startRecording() {
      // 获取视频元素
      const videoElement = this.$refs.videoElement;
      if (!videoElement || !videoElement.videoWidth) {
        this.$message.error('无法获取视频元素，请确保视频正在播放');
        return;
      }
      try {
        // 创建Canvas元素
        const canvas = document.createElement('canvas');
        canvas.width = videoElement.videoWidth || 1920; // 默认1920如果无法获取实际宽度
        canvas.height = videoElement.videoHeight || 1080; // 默认1080如果无法获取实际高度
        const ctx = canvas.getContext('2d');
        
        // 创建MediaRecorder实例，从Canvas流中录制
        const stream = canvas.captureStream(30); // 30fps

        // 检查支持的MIME类型
        let options;
        if (MediaRecorder.isTypeSupported('video/webm;codecs=h264')) {
          // 使用 H264 编码，通常具有更好的兼容性和性能
          options = {
            mimeType: 'video/webm;codecs=h264',
            videoBitsPerSecond: 2500000, // 2.5Mbps
            audioBitsPerSecond: 0 // 不录制音频
          };
        } else if (MediaRecorder.isTypeSupported('video/webm;codecs=vp9')) {
          // 降级到 VP9
          options = {
            mimeType: 'video/webm;codecs=vp9',
            videoBitsPerSecond: 2500000,
            audioBitsPerSecond: 0
          };
        } else {
          // 最后尝试 VP8
          options = {
            mimeType: 'video/webm;codecs=vp8',
            videoBitsPerSecond: 2500000,
            audioBitsPerSecond: 0
          };
        }

        // 创建 MediaRecorder 实例
        this.mediaRecorder = new MediaRecorder(stream, options);

        // 修改数据处理方式
        this.mediaRecorder.ondataavailable = (event) => {
          if (event.data && event.data.size > 0) {
            this.recordedChunks.push(event.data);
          }
        };
        
        // 每秒插入一个关键帧
        const videoTrack = stream.getVideoTracks()[0];
        if (videoTrack.getSettings) {
          try {
            const constraints = {
              frameRate: 30,
              keyFrameInterval: 1 // 每秒一个关键帧
            };
            videoTrack.applyConstraints(constraints);
          } catch (e) {
            console.warn('无法设置关键帧间隔:', e);
          }
        }

        // 创建帧捕获定时器
        this.frameTimer = setInterval(() => {
          if (videoElement.readyState === videoElement.HAVE_ENOUGH_DATA) {
            ctx.drawImage(videoElement, 0, 0, canvas.width, canvas.height);
          }
        }, 1000 / 30); // 30fps
        
        // 存储录制的数据块
        this.recordedChunks = [];
        
        // 配置数据收集
        this.mediaRecorder.ondataavailable = (event) => {
          if (event.data && event.data.size > 0) {
            this.recordedChunks.push(event.data);
          }
        };
        
        // 录制停止时的处理
        this.mediaRecorder.onstop = async () => {
          try {
            // 确保所有数据块都已收集
            await new Promise(resolve => setTimeout(resolve, 100));
            
            // 添加视频元数据
            const metadata = {
              codec: this.mediaRecorder.mimeType,
              duration: (Date.now() - this.recordStartTime) / 1000,
              width: canvas.width,
              height: canvas.height,
              framerate: 30
            };
            
            // 创建包含元数据的Blob
            const metadataChunk = new Blob([JSON.stringify(metadata)], { type: 'application/json' });
            const videoBlob = new Blob(this.recordedChunks, { type: this.mediaRecorder.mimeType });
            
            // 合并元数据和视频数据
            const finalBlob = new Blob([metadataChunk, videoBlob], { type: this.mediaRecorder.mimeType });
            
            // 使用 FileReader 确保数据完整性
            const reader = new FileReader();
            
            reader.onload = () => {
              const url = URL.createObjectURL(finalBlob);
              const a = document.createElement('a');
              document.body.appendChild(a);
              a.style.display = 'none';
              a.href = url;
              
              // 设置文件名
              const timestamp = new Date().toISOString().replace(/[:.]/g, '-');
              a.download = `record_${this.deviceId}_${timestamp}.webm`;
              
              // 触发下载
              a.click();
              
              // 清理
              setTimeout(() => {
                URL.revokeObjectURL(url);
                document.body.removeChild(a);
                
                this.isRecording = false;
                this.recordStartTime = null;
                this.recordedChunks = [];
                
                this.$message({
                  message: '录像已保存到您的下载文件夹',
                  type: 'success',
                  duration: 3000
                });
              }, 100);
            };
            
            reader.onerror = () => {
              throw new Error('文件保存失败');
            };
            
            // 开始读取文件
            reader.readAsArrayBuffer(finalBlob);
            
          } catch (error) {
            console.error('保存录像失败:', error);
            this.$message.error(`保存录像失败: ${error.message || '未知错误'}`);
            
            this.isRecording = false;
            this.recordStartTime = null;
            this.recordedChunks = [];
          }
        };
        
        // 配置视频编码器参数
        if ('VideoEncoder' in window) {
          try {
            const videoEncoder = new VideoEncoder({
              output: chunk => {
                if (chunk.type === 'key') {
                  // 强制插入关键帧
                  this.recordedChunks.push(chunk);
                }
              },
              error: e => console.error('视频编码器错误:', e)
            });

            // 配置编码器
            videoEncoder.configure({
              codec: 'vp09.00.10.08',
              width: canvas.width,
              height: canvas.height,
              bitrate: 2500000,
              framerate: 30,
              latencyMode: 'realtime',
              keyframeInterval: 30 // 每秒一个关键帧
            });
          } catch (e) {
            console.warn('高级视频编码器配置失败，使用默认配置:', e);
          }
        }

        // 开始录制 - 使用优化的时间间隔
        this.mediaRecorder.start(1000); // 每秒保存一个数据块，确保关键帧对齐
        this.isRecording = true;
        this.recordStartTime = Date.now();
        
        this.$message({
          message: '开始录像',
          type: 'success',
          duration: 2000
        });
        
        // 设置录像时长更新定时器
        this.recordingTimer = setInterval(() => {
          // 触发计算属性更新
          this.$forceUpdate();
        }, 1000);
        
      } catch (error) {
        console.error('开始录像失败:', error);
        this.$message.error(`开始录像失败: ${error.message || '未知错误'}`);
      }
    },
    
    // 停止录像
    stopRecording() {
      if (!this.mediaRecorder || this.mediaRecorder.state === 'inactive') {
        this.$message.error('没有正在进行的录像');
        return;
      }
      
      try {
        // 停止录制
        this.mediaRecorder.stop();
        
        // 清除定时器
        if (this.recordingTimer) {
          clearInterval(this.recordingTimer);
          this.recordingTimer = null;
        }
        
        // 清除帧捕获定时器
        if (this.frameTimer) {
          clearInterval(this.frameTimer);
          this.frameTimer = null;
        }
        
      } catch (error) {
        console.error('停止录像失败:', error);
        this.$message.error(`停止录像失败: ${error.message || '未知错误'}`);
        
        // 重置录像状态
        this.isRecording = false;
        this.recordStartTime = null;
      }
    },
    // 显示设备信息
    showDeviceInfo() {
      // 更新设备信息
      this.updateDeviceInfo();
      this.deviceInfoVisible = true;
    },

    // 更新设备信息
    updateDeviceInfo() {
      const videoElement = this.$refs.videoElement;
      if (videoElement && this.flvPlayer) {
        getDeviceInfo(this.deviceId).then((res) => {
          this.deviceInfo = {
            ...res,
            deviceId: res.device_id,
            deviceName: res.device_name,
            deviceType: res.device_type,
            online: res.device_state === "ONLINE" ? true : false,
            resolution: videoElement.videoWidth ? `${videoElement.videoWidth}x${videoElement.videoHeight}` : '-',
            bitrate: this.flvPlayer.statisticsInfo ? `${Math.round(this.flvPlayer.statisticsInfo.speed * 8 / 1024)} kbps` : '-'
          };
          console.log('设备信息', this.deviceInfo);
        })
        
      }
    },

    // 截图功能
    takeSnapshot() {
      const videoElement = this.$refs.videoElement;
      if (!videoElement || !videoElement.videoWidth) {
        this.$message.error('视频未就绪，无法截图');
        return;
      }

      try {
        const canvas = document.createElement('canvas');
        const ctx = canvas.getContext('2d');
        
        // 设置canvas尺寸
        if (this.rotationDegree === 90 || this.rotationDegree === 270) {
          canvas.width = videoElement.videoHeight;
          canvas.height = videoElement.videoWidth;
        } else {
          canvas.width = videoElement.videoWidth;
          canvas.height = videoElement.videoHeight;
        }

        // 根据旋转角度调整绘制
        ctx.save();
        ctx.translate(canvas.width / 2, canvas.height / 2);
        ctx.rotate((this.rotationDegree * Math.PI) / 180);
        ctx.drawImage(
          videoElement,
          -videoElement.videoWidth / 2,
          -videoElement.videoHeight / 2,
          videoElement.videoWidth,
          videoElement.videoHeight
        );
        ctx.restore();

        // 创建下载链接
        const link = document.createElement('a');
        link.download = `snapshot_${this.deviceId}_${new Date().toISOString().replace(/[:.]/g, '-')}.png`;
        link.href = canvas.toDataURL('image/png');
        link.click();

        this.$message.success('截图已保存');
      } catch (error) {
        console.error('截图失败:', error);
        this.$message.error('截图失败');
      }
    },

    // 旋转视频
    rotateVideo() {
      this.rotationDegree = (this.rotationDegree + 90) % 360;
      const videoElement = this.$refs.videoElement;
      const container = videoElement?.parentElement;
      
      if (videoElement && container) {
        // 移除所有旋转类
        container.classList.remove('rotate-0', 'rotate-90', 'rotate-180', 'rotate-270');
        // 添加当前旋转角度的类
        container.classList.add(`rotate-${this.rotationDegree}`);
        
        // 获取视频和容器的尺寸
        const videoWidth = videoElement.videoWidth || videoElement.clientWidth;
        const videoHeight = videoElement.videoHeight || videoElement.clientHeight;
        const containerRect = container.getBoundingClientRect();
        const containerWidth = containerRect.width;
        const containerHeight = containerRect.height;
        
        // 计算视频比例
        const videoRatio = videoWidth / videoHeight || 16/9;
        
        // 根据旋转角度调整视频尺寸和位置
        if (this.rotationDegree === 90 || this.rotationDegree === 270) {
          // 设置基础样式
          videoElement.style.position = 'absolute';
          videoElement.style.top = '50%';
          videoElement.style.left = '50%';
          videoElement.style.transformOrigin = 'center center';
          
          // 计算旋转后的尺寸
          const availableWidth = containerHeight;
          const availableHeight = containerWidth;
          const rotatedRatio = 1 / videoRatio; // 旋转后的宽高比
          
          if (availableWidth / availableHeight > rotatedRatio) {
            // 以高度为基准
            const width = availableHeight * rotatedRatio;
            videoElement.style.width = `${width}px`;
            videoElement.style.height = `${availableHeight}px`;
          } else {
            // 以宽度为基准
            const height = availableWidth / rotatedRatio;
            videoElement.style.width = `${availableWidth}px`;
            videoElement.style.height = `${height}px`;
          }
          
          // 应用旋转变换
          const rotateValue = this.rotationDegree === 90 ? 90 : 270;
          videoElement.style.transform = `translate(-50%, -50%) rotate(${rotateValue}deg)`;
          
        } else {
          // 0度或180度时的处理
          videoElement.style.position = 'absolute';
          videoElement.style.top = '50%';
          videoElement.style.left = '50%';
          videoElement.style.transformOrigin = 'center center';
          
          // 计算适合容器的尺寸
          if (containerWidth / containerHeight > videoRatio) {
            // 以高度为基准
            const width = containerHeight * videoRatio;
            videoElement.style.width = `${width}px`;
            videoElement.style.height = '100%';
          } else {
            // 以宽度为基准
            const height = containerWidth / videoRatio;
            videoElement.style.width = '100%';
            videoElement.style.height = `${height}px`;
          }
          
          // 应用旋转变换
          const rotateValue = this.rotationDegree === 0 ? 0 : 180;
          videoElement.style.transform = `translate(-50%, -50%) rotate(${rotateValue}deg)`;
        }
        
        // 重置最大尺寸限制
        videoElement.style.maxWidth = 'none';
        videoElement.style.maxHeight = 'none';
      }
    },

    // 喊话功能
    async startTalk() {
      if (this.isTalking) {
        this.stopTalk();
        return;
      }

      try {
        const stream = await navigator.mediaDevices.getUserMedia({ audio: true });
        this.isTalking = true;
        this.$message.success('开始对讲');
        
        // TODO: 实现对讲功能，需要与设备端集成
        // 这里需要根据实际的设备通信协议来实现
        // this.startTalkToDevice(stream);
        
      } catch (error) {
        console.error('获取麦克风失败:', error);
        this.$message.error('无法访问麦克风');
      }
    },

    // 停止喊话
    stopTalk() {
      this.isTalking = false;
      // TODO: 停止对讲
      // 这里需要根据实际的设备通信协议来实现
      // this.stopTalkToDevice();
      this.$message.info('结束对讲');
    },
    
    // 清理计时器
    clearRecordingTimer() {
      if (this.recordingTimer) {
        clearInterval(this.recordingTimer);
        this.recordingTimer = null;
      }
    },

    // 处理视频元数据加载完成事件
    handleVideoMetadata() {
      const videoElement = this.$refs.videoElement;
      if (videoElement) {
        // 更新设备信息中的分辨率
        this.deviceInfo.resolution = `${videoElement.videoWidth}x${videoElement.videoHeight}`;
        
        // 重新计算视频尺寸和位置
        if (this.rotationDegree !== 0) {
          this.rotateVideo();
        }
      }
    },

    // 处理窗口大小变化
    handleResize() {
      // 使用防抖处理窗口大小变化
      if (this.resizeTimer) {
        clearTimeout(this.resizeTimer);
      }
      
      this.resizeTimer = setTimeout(() => {
        // 重新计算视频尺寸和位置
        if (this.rotationDegree !== 0) {
          this.rotateVideo();
        }
      }, 200); // 200ms防抖延迟
    }
  }
}
</script>

<style scoped>
.flv-player-container {
  width: 100%;
  height: 100%;
  background-color: #000;
  position: relative;
  overflow: hidden;
  display: flex;
  flex-direction: column;
  border-radius: 8px;
}

.video-player {
  width: 100%;
  height: 100%;
  position: relative;
  overflow: hidden;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}

.video-js {
  width: 100%;
  height: 100%;
  object-fit: contain;
  display: block;
  transition: transform 0.3s ease;
  position: absolute;
  background-color: #000;
  transform-origin: center center;
  margin: auto;
}

/* 视频播放器基础容器 */
.video-player {
  width: 100%;
  height: 100%;
  position: relative;
  overflow: hidden;
  display: flex;
  align-items: center;
  justify-content: center;
  background-color: #000;
}

/* 视频元素基础样式 */
.video-js {
  position: absolute;
  width: 100%;
  height: 100%;
  object-fit: contain;
  transition: transform 0.3s ease;
  transform-origin: center center;
}

/* 旋转状态的基础样式 */
.video-player .video-js {
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
}

/* 90度旋转状态 */
.video-player.rotate-90 {
  height: 100%;
}

.video-player.rotate-90 .video-js {
  transform: translate(-50%, -50%) rotate(90deg);
  width: auto;
  height: 100%;
  max-width: none;
  max-height: none;
}

/* 180度旋转状态 */
.video-player.rotate-180 .video-js {
  transform: translate(-50%, -50%) rotate(180deg);
}

/* 270度旋转状态 */
.video-player.rotate-270 {
  height: 100%;
}

.video-player.rotate-270 .video-js {
  transform: translate(-50%, -50%) rotate(270deg);
  width: auto;
  height: 100%;
  max-width: none;
  max-height: none;
}

/* 确保视频在所有状态下保持居中 */
.video-player::before {
  content: '';
  display: block;
  padding-top: 56.25%; /* 16:9 比例 */
}

/* 移除旋转状态下的padding */
.video-player.rotate-90::before,
.video-player.rotate-270::before {
  display: none;
}

.controls {
  padding: 12px 20px;
  display: flex;
  gap: 12px;
  justify-content: flex-end;
  width: 100%;
  z-index: 1000;
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  /* background: linear-gradient(to top, rgba(0, 0, 0, 0.8) 0%, rgba(0, 0, 0, 0.6) 50%, rgba(0, 0, 0, 0) 100%); */
  transition: opacity 0.3s ease;
  opacity: 0;
}

.flv-player-container:hover .controls {
  opacity: 1;
  transform: translateY(0);
}

.control-btn {
  padding: 8px !important;
  border: none !important;
  background-color: rgba(255, 255, 255, 0) !important;
  margin: 0 4px !important;
  /* box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2); */
  transition: all 0.2s cubic-bezier(0.4, 0, 0.2, 1);
  border-radius: 50% !important;
  width: 40px !important;
  height: 40px !important;
  display: flex !important;
  align-items: center !important;
  justify-content: center !important;
  backdrop-filter: blur(4px);
  -webkit-backdrop-filter: blur(4px);
}

/* 全屏模式样式 */
.flv-player-container:fullscreen,
.flv-player-container:-webkit-full-screen,
.flv-player-container:-moz-full-screen {
  background: #000;
  width: 100vw;
  height: 100vh;
  display: flex;
  align-items: center;
  justify-content: center;
}

.flv-player-container:fullscreen .video-js,
.flv-player-container:-webkit-full-screen .video-js,
.flv-player-container:-moz-full-screen .video-js {
  max-height: 100vh;
  max-width: 100vw;
  margin: auto;
}

.flv-player-container:fullscreen .controls,
.flv-player-container:-webkit-full-screen .controls,
.flv-player-container:-moz-full-screen .controls {
  padding-bottom: max(env(safe-area-inset-bottom, 20px), 30px);
  opacity: 0;
  transition: opacity 0.3s ease;
}

.flv-player-container:fullscreen:hover .controls,
.flv-player-container:-webkit-full-screen:hover .controls,
.flv-player-container:-moz-full-screen:hover .controls {
  opacity: 1;
}

.control-btn:hover {
  background-color: rgba(255, 255, 255, 0.25) !important;
  transform: translateY(-2px) scale(1.05);
  box-shadow: 0 6px 12px rgba(0, 0, 0, 0.4);
}

.control-btn:active {
  background-color: rgba(255, 255, 255, 0.3) !important;
  transform: translateY(0) scale(0.98);
  box-shadow: 0 2px 4px rgba(0, 0, 0, 0.3);
}

.control-btn i {
  color: #fff;
  font-size: 18px;
  text-shadow: 0 1px 3px rgba(0, 0, 0, 0.3);
  transition: all 0.2s ease;
}

.control-btn:hover i {
  transform: scale(1.1);
}

/* 控制栏渐变背景 */
.controls::before {
  content: '';
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  height: 120px;
  /* background: linear-gradient(to top, rgba(0, 0, 0, 0.7) 0%, rgba(0, 0, 0, 0) 100%); */
  pointer-events: none;
  z-index: -1;
}

/* 全屏时的控制栏位置调整 */
:fullscreen .controls {
  bottom: 0;
  padding-bottom: 30px;
}

:-webkit-full-screen .controls {
  bottom: 0;
  padding-bottom: 30px;
}

:-moz-full-screen .controls {
  bottom: 0;
  padding-bottom: 30px;
}

.error-message {
  color: #f56c6c;
  padding: 20px;
  text-align: center;
  background-color: rgba(0, 0, 0, 0.8);
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
  border-radius: 6px;
  min-width: 200px;
  box-shadow: 0 4px 12px rgba(0, 0, 0, 0.15);
  display: flex;
  flex-direction: column;
  align-items: center;
  gap: 16px;
}

.refresh-button {
  background-color: #409eff;
  color: white;
  border: none;
  padding: 8px 16px;
  border-radius: 4px;
  cursor: pointer;
  display: flex;
  align-items: center;
  gap: 8px;
  transition: all 0.3s ease;
}

.refresh-button:hover {
  background-color: #66b1ff;
  transform: scale(1.05);
}

.refresh-button:active {
  transform: scale(0.95);
}

.refresh-button i {
  font-size: 16px;
}

.loading-message {
  color: white;
  padding: 16px 24px;
  text-align: center;
  background-color: rgba(0, 0, 0, 0.7);
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
  border-radius: 6px;
  backdrop-filter: blur(4px);
  box-shadow: 0 4px 12px rgba(0, 0, 0, 0.2);
  animation: pulse 1.5s infinite;
}

/* 设备信息对话框样式 */
:deep(.device-info-dialog) {
  border-radius: 8px;
  overflow: hidden;
  background-color: rgba(0, 0, 0, 0.8) !important;
  width: 360px !important;
  transition: all 0.3s ease-in-out;
  box-shadow: 0 4px 12px rgba(0, 0, 0, 0.3) !important;
}

:deep(.device-info-dialog.el-dialog__wrapper) {
  backdrop-filter: blur(5px);
}

:deep(.device-info-dialog .el-dialog) {
  transform-origin: center;
  animation: dialogFadeIn 0.3s;
}

@keyframes dialogFadeIn {
  from {
    opacity: 0;
    transform: scale(0.95);
  }
  to {
    opacity: 1;
    transform: scale(1);
  }
}

:deep(.device-info-dialog .el-dialog__header) {
  background-color: transparent !important;
  padding: 15px !important;
  border-bottom: 1px solid rgba(255, 255, 255, 0.1) !important;
}
:deep(.device-info-dialog .el-dialog__title) {
  color: white !important;
  font-size: 24px !important;
}
:deep(.el-dialog__body) {
  padding: 8px;
  font-size: 24px !important;
}

:deep(.device-info-dialog .el-dialog__headerbtn .el-dialog__close) {
  color: white !important;
  position: absolute;
  top: -10px;
  right: -10px;
}

.device-info {
  padding: 15px;
}

.device-info p {
  margin: 8px 0;
  line-height: 1.5;
  display: flex;
  justify-content: space-between;
  padding-bottom: 8px;
  color: white;
}

.device-info p:last-child {
  border-bottom: none;
}

.device-info strong {
  color: rgba(255, 255, 255, 0.7);
  margin-right: 12px;
  width: 140px;
}

/* 喊话按钮激活状态 */
.control-btn.el-button--primary {
  background-color: #409eff !important;
}

.control-btn.el-button--primary i {
  color: #fff;
}

@keyframes pulse {
  0% {
    opacity: 0.7;
  }
  50% {
    opacity: 1;
  }
  100% {
    opacity: 0.7;
  }
}
.record-controls {
  position: absolute;
  left: 20px;
  top: 30px;
  z-index: 10;
}

/* 录像状态指示器 */
.record-status {
  /* position: absolute;
  top: 20px;
  left: 20px; */
  display: flex;
  align-items: center;
  gap: 8px;
  color: #fff;
  font-size: 16px;
  background: rgba(0, 0, 0, 0.5);
  padding: 6px 12px;
  border-radius: 4px;
  z-index: 100;
}

.record-indicator {
  width: 12px;
  height: 12px;
  background-color: #f14d4d;
  border-radius: 50%;
  animation: pulse 1.5s infinite;
}
/* 视频旋转时的容器样式 */
.video-container {
  position: relative;
  width: 100%;
  height: 100%;
  display: flex;
  align-items: center;
  justify-content: center;
  overflow: hidden;
}

/* 适配不同旋转角度的视频尺寸 */
.video-js[style*="rotate(90deg)"],
.video-js[style*="rotate(270deg)"] {
  width: auto !important;
  height: 100% !important;
  max-height: -webkit-fill-available !important;
}
</style>